.wp-block-jetpack-top-posts{margin-bottom:1.5em}.wp-block-jetpack-top-posts img{width:100%}.wp-block-jetpack-top-posts span{display:block;word-wrap:break-word}.wp-block-jetpack-top-posts.is-list-layout .jetpack-top-posts-item{margin-bottom:1.5em}.wp-block-jetpack-top-posts.is-grid-layout .jetpack-top-posts-wrapper{align-items:flex-start;display:grid;gap:16px 12px;grid:auto/repeat(6,1fr)}@media only screen and (max-width:600px){.wp-block-jetpack-top-posts.is-grid-layout .jetpack-top-posts-wrapper{display:block}.wp-block-jetpack-top-posts.is-grid-layout .jetpack-top-posts-wrapper .jetpack-top-posts-mock-thumbnail{display:none}.wp-block-jetpack-top-posts.is-grid-layout .jetpack-top-posts-wrapper .jetpack-top-posts-item{margin-bottom:1.5em}}.wp-block-jetpack-top-posts.is-grid-layout .jetpack-top-posts-mock-thumbnail{background-color:#f0f0f0;height:0;padding-bottom:75%;position:relative;width:100%}.wp-block-jetpack-top-posts.is-grid-layout .jetpack-top-posts-thumbnail{aspect-ratio:4/3;height:auto;max-width:100%;object-fit:cover}.wp-block-jetpack-top-posts.is-grid-layout .jetpack-top-posts-item{grid-column:span 2}.wp-block-jetpack-top-posts.is-grid-layout[data-item-count="2"] .jetpack-top-posts-item,.wp-block-jetpack-top-posts.is-grid-layout[data-item-count="4"] .jetpack-top-posts-item,.wp-block-jetpack-top-posts.is-grid-layout[data-item-count="5"] .jetpack-top-posts-item:nth-child(5n),.wp-block-jetpack-top-posts.is-grid-layout[data-item-count="5"] .jetpack-top-posts-item:nth-child(5n-1),.wp-block-jetpack-top-posts.is-grid-layout[data-item-count="7"] .jetpack-top-posts-item:nth-child(5n),.wp-block-jetpack-top-posts.is-grid-layout[data-item-count="7"] .jetpack-top-posts-item:nth-child(5n-1),.wp-block-jetpack-top-posts.is-grid-layout[data-item-count="7"] .jetpack-top-posts-item:nth-child(7n),.wp-block-jetpack-top-posts.is-grid-layout[data-item-count="7"] .jetpack-top-posts-item:nth-child(7n-1){grid-column:span 3}